==> freebsd-buildutils_5.2.1+20041028.1.orig.tar.gz: src/usr.bin/make/pathnames.h <==
/*
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)pathnames.h	8.2 (Berkeley) 4/28/95
 * $FreeBSD: src/usr.bin/make/pathnames.h,v 1.12 2002/05/24 15:51:27 ru Exp $
 */

#ifndef _PATH_OBJDIR
#define	_PATH_OBJDIR		"obj"
#endif /* ! _PATH_OBJDIR */
#ifndef _PATH_OBJDIRPREFIX
#define	_PATH_OBJDIRPREFIX	"/usr/obj"
#endif /* ! _PATH_OBJDIRPREFIX */
#ifndef _PATH_DEFSHELLDIR
#define	_PATH_DEFSHELLDIR	"/bin"
#endif /* ! _PATH_DEFSHELLDIR */
#ifndef _PATH_DEFSYSMK
#define	_PATH_DEFSYSMK		"sys.mk"
#endif /* ! _PATH_DEFSYSMK */
#ifndef _PATH_DEFSYSPATH
#define	_PATH_DEFSYSPATH	"/usr/share/mk"
#endif /* ! _PATH_DEFSYSPATH */

==> freebsd-buildutils_7.0.orig.tar.gz: src/usr.bin/make/pathnames.h <==
/*-
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)pathnames.h	8.2 (Berkeley) 4/28/95
 * $FreeBSD: src/usr.bin/make/pathnames.h,v 1.14 2005/03/11 13:02:38 harti Exp $
 */

#ifndef pathnames_h_235b888a
#define	pathnames_h_235b888a

#ifndef PATH_OBJDIR
#define	PATH_OBJDIR		"obj"
#endif /* ! PATH_OBJDIR */

#ifndef PATH_OBJDIRPREFIX
#define	PATH_OBJDIRPREFIX	"/usr/obj"
#endif /* ! PATH_OBJDIRPREFIX */

#ifndef PATH_DEFSHELLDIR
#define	PATH_DEFSHELLDIR	"/bin"
#endif /* ! PATH_DEFSHELLDIR */

#ifndef PATH_DEFSYSMK
#define	PATH_DEFSYSMK		"sys.mk"
#endif /* ! PATH_DEFSYSMK */

#ifndef PATH_DEFSYSPATH
#define	PATH_DEFSYSPATH	"/usr/share/mk"
#endif /* ! PATH_DEFSYSPATH */

#endif /* pathnames_h_235b888a */
